︠bb00c1e4-1a53-4601-8676-8d3666df9173︠
%md(hide = False)

### Use [mhchem](http://www.ctan.org/pkg/mhchem) with LaTeX in SMC worsheet.

No need to include special packages. Supported by MathJax.

Here is a simplified version of the Urey reaction.
This reaction summarizes the role of the geosphere
in the carbon cycle.

$$\ce{CaSiO3 + CO2 <=>[weathering][outgassing] CaCO3 + SiO2}$$
︡75cfbd2b-7cc3-4b23-bdaf-1353c2823ed9︡{"done":true,"md":"\n### Use [mhchem](http://www.ctan.org/pkg/mhchem) with LaTeX in SMC worsheet.\n\nNo need to include special packages. Supported by MathJax.\n\nHere is a simplified version of the Urey reaction.\nThis reaction summarizes the role of the geosphere\nin the carbon cycle.\n\n$$\\ce{CaSiO3 + CO2 <=>[weathering][outgassing] CaCO3 + SiO2}$$"}
︠c90a6081-54f8-4b0e-a944-b617eb196f97︠

︡511a36dd-2367-4389-923c-c8acda5da0cc︡
︠77f154d4-9e11-482a-b4de-6633e2c1ea9f︠
latex.add_package_to_preamble_if_available('chemfig')
#Can create chemfig figures [chemfig](https://www.ctan.org/pkg/chemfig)

%latex
\chemfig{(-[:0,1.5,,,draw=none]\scriptstyle\color{red}0)
(-[1]1)(-[:45,1.5,,,draw=none]\scriptstyle\color{red}45)
(-[2]2)(-[:90,1.5,,,draw=none]\scriptstyle\color{red}90)
(-[3]3)(-[:135,1.5,,,draw=none]\scriptstyle\color{red}135)
(-[4]4)(-[:180,1.5,,,draw=none]\scriptstyle\color{red}180)
(-[5]5)(-[:225,1.5,,,draw=none]\scriptstyle\color{red}225)
(-[6]6)(-[:270,1.5,,,draw=none]\scriptstyle\color{red}270)
(-[7]7)(-[:315,1.5,,,draw=none]\scriptstyle\color{red}315)
-0}

\chemfig{C(-[:0]H)(-[:90]H)(-[:180]H)(-[:270]H)}
︡a65240b5-ac49-4890-8007-274162572dfa︡{"file":{"filename":"/tmp/tmp_QbDyN.png","show":true,"text":null,"uuid":"59dd8cec-8a66-4623-9a33-d1a4209024c7"},"once":false}︡{"done":true}︡
︠5a92db27-1758-4b7d-a8f9-584cd2c4a369s︠
latex.add_package_to_preamble_if_available('tikz')
#Can also generate tikz figures (see http://www.texample.net/tikz/examples/ for some great examples)

%latex

\begin{tikzpicture}
	\draw[step=1cm, color=gray,very thin](-1,-1) grid (5,4);
	\draw[very thick,->] (0,0) -- (0,4) node[anchor=west]{$\infty$};
	\draw[very thick,->] (4,0) -- (4,4) node[anchor=west]{$\infty$};
	\draw[very thick] (0,0)--(4,0) node[anchor=north]{x=L};
	\node at (0,-.25) {x = 0};
	\draw[->] (-1,0) -- (5,0)node[anchor=west]{$x$};

\end{tikzpicture}
︡41c0ada9-75cb-4cbc-8c47-566352d0cfb2︡{"file":{"filename":"/tmp/tmp3KmtwZ.png","show":true,"text":null,"uuid":"ff458402-ae0b-4f4d-ad06-36e53e2eb142"},"once":false}︡{"done":true}︡
︠6f052613-97c5-49fc-b074-d842a3db9a51s︠
# plot 8th (or other) roots of unity
from matplotlib import ticker
rootnum = 8
roots = [e^(i*2*k*pi/rootnum) for k in range(rootnum)]
xypoints = [(z.real(),z.imag()) for z in roots]
labels = [text("$"+latex(z)+"$",(z.real() + 0.1,z.imag() - 0.2)) for z in roots]
t = "%sth roots of unity\n"%rootnum + r"$e^{i\frac{2k\pi}{%s}},k=0,1,\ldots,5$"%rootnum
p = point(xypoints, aspect_ratio = 1, title = t, size = 25, marker = 'o')
TT = ticker.FormatStrFormatter('%3.1fi')
c = circle((0, 0), 1, alpha = 0.5)
g = p + sum(labels) + c
g.show(xmin = -1.5, xmax = 1.5, ymin = -1.5, ymax = 1.5,
       title = t, tick_formatter = [None, TT], frame = True)
︡5688e564-2f2c-491c-90a6-5cb4604ba17a︡{"file":{"filename":"/projects/bd2ee9ae-5747-48e0-ba1e-61226b2bac71/.sage/temp/compute5-us/2212/tmp_wpfDdf.svg","show":true,"text":null,"uuid":"732c3140-3c8e-47d2-9b86-5c785f094753"},"once":false}︡{"html":"<div align='center'></div>"}︡{"done":true}︡
︠7136c4d7-1a31-4202-8e61-186a85290b3as︠
%sage r.set_plot_options(width=11, height=6)
︡213a5800-c466-4b85-9033-09c31045b8c7︡{"done":true}︡
︠9d17bdcf-dc96-4c69-81f6-8c1dee525da2︠
%r
# 1-liner boxplot of life expectancy vs region from World Health Organization
# data from Global Health Observatory http://apps.who.int/gho/data/node.main
setwd(file.path(Sys.getenv("HOME"),"projects/Cool_Things_With_SMC"))
WHO = read.csv('WHO.csv')
boxplot(WHO$LifeExpectancy ~ WHO$Region,show.names = T, main = "Life Expectancy for Geographic Regions")

︡91e4c114-1423-49f7-82d4-1df383db8147︡{"stdout":"\n"}︡{"file":{"filename":"/tmp/f3248576-56c6-4680-87b4-f2bbe9fda43b.svg","show":true,"text":null,"uuid":"1179cae8-99de-4de8-acda-0485724549f6"},"once":false}︡{"stdout":"\n"}︡{"done":true}︡
︠04611884-c033-4a8c-b68d-84b0a291ec0a︠









